#[non_exhaustive]pub enum ProfileFieldValue {
AvatarUrl(OwnedMxcUri),
DisplayName(String),
TimeZone(String),
Status(StatusProfileField),
Call(CallProfileField),
}Expand description
The possible values of a field of a user’s profile.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AvatarUrl(OwnedMxcUri)
The user’s avatar URL.
DisplayName(String)
The user’s display name.
TimeZone(String)
The user’s time zone.
Status(StatusProfileField)
unstable-msc4426 only.The user’s current status.
This uses the unstable prefix defined in MSC4426.
Call(CallProfileField)
unstable-msc4426 only.The user’s call indicator.
This uses the unstable prefix defined in MSC4426.
Implementations
Sourceimpl ProfileFieldValue
impl ProfileFieldValue
Sourcepub fn new(field: &str, value: Value) -> Result<ProfileFieldValue, Error>
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn new(field: &str, value: Value) -> Result<ProfileFieldValue, Error>
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Construct a new ProfileFieldValue with the given field and value.
Prefer to use the public variants of ProfileFieldValue where possible; this constructor is
meant to be used for unsupported fields only and does not allow setting arbitrary data for
supported ones.
Errors
Returns an error if the field is known and serialization of value to the corresponding
ProfileFieldValue variant fails.
Sourcepub fn field_name(&self) -> ProfileFieldName
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn field_name(&self) -> ProfileFieldName
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.The name of the field for this value.
Sourcepub fn value(&self) -> Cow<'_, Value>
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn value(&self) -> Cow<'_, Value>
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Returns the value of the field.
Prefer to use the public variants of ProfileFieldValue where possible; this method is
meant to be used for custom fields only.