pub struct ProfileFieldValueVisitor(/* private fields */);Expand description
Helper type to deserialize ProfileFieldValue.
If the field name is set, this will try to deserialize a map entry using this key, otherwise this will deserialize the first key-value pair encountered.
Implementations
Sourceimpl ProfileFieldValueVisitor
impl ProfileFieldValueVisitor
Sourcepub fn new(field: Option<ProfileFieldName>) -> ProfileFieldValueVisitor
Available on crate feature events only.
pub fn new(field: Option<ProfileFieldName>) -> ProfileFieldValueVisitor
events only.Construct a ProfileFieldValueVisitor for the given optional field name.