pub struct UserProfile(/* private fields */);Expand description
All the profile information for a user.
Implementations
Sourceimpl UserProfile
impl UserProfile
Sourcepub fn new() -> UserProfile
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn new() -> UserProfile
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Creates a new empty UserProfile.
Sourcepub fn get(&self, field: &str) -> Option<&Value>
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn get(&self, field: &str) -> Option<&Value>
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Returns the value of the given profile field.
Sourcepub fn get_static<F>(
&self,
) -> Result<Option<<F as StaticProfileField>::Value>, Error>where
F: StaticProfileField,
Available on crate feature api and (crate features client-api-c or client-api-s) and (crate features client or server) only.
pub fn get_static<F>(
&self,
) -> Result<Option<<F as StaticProfileField>::Value>, Error>where
F: StaticProfileField,
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Returns the value of the given StaticProfileField.
Returns Ok(Some(_)) if the field is present and the value was deserialized
successfully, Ok(None) if the field is not set, or an error if deserialization of the
value failed.